@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2010,2012,2014,2018 Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007-2010,2012,2014,2018,2019 Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -52,7 +52,7 @@
 /**                # Version 5.1  : from : 16 jun 2008     **/
 /**                                 to   : 15 aug 2010     **/
 /**                # Version 6.0  : from : 01 dec 2012     **/
-/**                                 to   : 10 jul 2018     **/
+/**                                 to   : 16 apr 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -233,6 +233,7 @@ char *                      argv[])
   subsFill ("DUMMYVERSION", EXPAND (SCOTCH_VERSION_NUM));
   subsFill ("DUMMYRELEASE", EXPAND (SCOTCH_RELEASE_NUM));
   subsFill ("DUMMYPATCHLEVEL", EXPAND (SCOTCH_PATCHLEVEL_NUM));
+  subsFill ("DUMMYSIZEARCHDOM", subsSize (sizeof (ArchDom)));
   subsFill ("DUMMYSIZEARCH", subsSize (sizeof (Arch)));
   subsFill ("DUMMYSIZEGEOM", subsSize (sizeof (Geom)));
   subsFill ("DUMMYSIZEGRAPH", subsSize (sizeof (Graph)));
