@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -55,7 +55,7 @@
 /**                # Version 5.1  : from : 11 dec 2008     **/
 /**                                 to   : 17 jul 2011     **/
 /**                # Version 6.0  : from : 01 jan 2012     **/
-/**                                 to   : 10 jul 2018     **/
+/**                                 to   : 27 apr 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -118,7 +118,7 @@ char *                      argv[])
 
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
-    return     (0);
+    return     (EXIT_SUCCESS);
   }
 
   flagval = C_FLAGNONE;
@@ -132,7 +132,7 @@ char *                      argv[])
         fileBlockName (C_fileTab, C_fileNum ++) = argv[i];
       else {
         errorPrint ("main: too many file names given");
-        return     (1);
+        return     (EXIT_FAILURE);
       }
     }
     else {                                        /* If found an option name */
@@ -146,13 +146,13 @@ char *                      argv[])
           SCOTCH_stratInit (&bipastrat);
           if ((SCOTCH_stratGraphBipart (&bipastrat, &argv[i][2])) != 0) {
             errorPrint ("main: invalid bipartitioning strategy");
-            return     (1);
+            return     (EXIT_FAILURE);
           }
           break;
         case 'H' :                                /* Give the usage message */
         case 'h' :
           usagePrint (stdout, C_usageList);
-          return     (0);
+          return     (EXIT_SUCCESS);
         case 'L' :                                /* Input vertex list */
         case 'l' :
           flagval |= C_FLAGVRTINP;
@@ -161,12 +161,12 @@ char *                      argv[])
           break;
         case 'V' :
           fprintf (stderr, "amk_grf, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS, France\n");
-          fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
-          return  (0);
+          fprintf (stderr, SCOTCH_COPYRIGHT_STRING "\n");
+          fprintf (stderr, SCOTCH_LICENSE_STRING "\n");
+          return  (EXIT_SUCCESS);
         default :
           errorPrint ("main: unprocessed option '%s'", argv[i]);
-          return     (1);
+          return     (EXIT_FAILURE);
       }
     }
   }
@@ -187,24 +187,23 @@ char *                      argv[])
         (listnbr < 0)                               ||
         (listnbr > vertnbr)) {
       errorPrint ("main: bad list input (1)");
-      return     (1);
+      return     (EXIT_FAILURE);
     }
-    if ((listtab = (SCOTCH_Num *) memAlloc (listnbr * sizeof (SCOTCH_Num) + 1)) == NULL) {
+    if ((listtab = (SCOTCH_Num *) memAlloc (listnbr * sizeof (SCOTCH_Num))) == NULL) {
       errorPrint ("main: out of memory (1)");
-      return     (1);
+      return     (EXIT_FAILURE);
     }
     for (listnum = 0; listnum < listnbr; listnum ++) { /* Read list data */
       if (intLoad (C_filepntrvrtinp, &listtab[listnum]) != 1) {
         errorPrint ("main: bad list input (2)");
-        return     (1);
+        return     (EXIT_FAILURE);
       }
     }
     intSort1asc1 (listtab, listnbr);
     for (listnum = 0; listnum < listnbr - 1; listnum ++) { /* Search for duplicates */
       if (listtab[listnum] == listtab[listnum + 1]) {
         errorPrint ("main: duplicate list labels");
-        memFree    (listtab);
-        return     (1);
+        return     (EXIT_FAILURE);
       }
     }
 
@@ -213,8 +212,7 @@ char *                      argv[])
 
       if ((sorttab = (C_VertSort *) memAlloc (vertnbr * sizeof (C_VertSort))) == NULL) {
         errorPrint ("main: out of memory (2)");
-        memFree    (listtab);
-        return     (1);
+        return     (EXIT_FAILURE);
       }
       for (vertnum = 0; vertnum < vertnbr; vertnum ++) { /* Initialize sort area */
         sorttab[vertnum].vlblnum = vlbltab[vertnum];
@@ -228,9 +226,7 @@ char *                      argv[])
         if ((vertnum >= vertnbr) ||               /* If label not found                           */
             (sorttab[vertnum].vlblnum > listtab[listnum])) {
           errorPrint ("main: list label '" SCOTCH_NUMSTRING "' not in graph", (SCOTCH_Num) listtab[listnum]);
-          memFree    (sorttab);
-          memFree    (listtab);
-          return     (1);
+          return     (EXIT_FAILURE);
         }
         listtab[listnum] = sorttab[vertnum ++].vertnum; /* Replace label by number */
       }
@@ -253,5 +249,5 @@ char *                      argv[])
   if (listtab != NULL)                            /* If vertex list provided  */
     memFree (listtab);                            /* Free it                  */
 
-  return (0);
+  return (EXIT_SUCCESS);
 }
