@@ -1,4 +1,4 @@
-/* Copyright 2009-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2009-2012,2014,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -42,7 +42,7 @@
 /**   DATES      : # Version 5.1  : from : 26 apr 2009     **/
 /**                                 to   : 14 feb 2011     **/
 /**                # Version 6.0  : from : 01 jan 2012     **/
-/**                                 to   : 10 jul 2018     **/
+/**                                 to   : 17 apr 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -91,7 +91,7 @@ char *                      argv[])
 
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
-    return     (0);
+    return     (EXIT_SUCCESS);
   }
 
   fileBlockInit (C_fileTab, C_FILENBR);           /* Set default stream pointers */
@@ -101,7 +101,7 @@ char *                      argv[])
       if (C_paraNum < 1) {                        /* If number of parameters not reached              */
         if ((p[C_paraNum ++] = atoi (argv[i])) < 1) { /* Get number of parts                          */
           errorPrint ("main: invalid number of parts '%s'", argv[i]);
-          return     (1);
+          return     (EXIT_FAILURE);
         }
         continue;                                 /* Process the other parameters */
       }
@@ -109,7 +109,7 @@ char *                      argv[])
         fileBlockName (C_fileTab, C_fileNum ++) = argv[i];
       else {
         errorPrint ("main: too many file names given");
-        return     (1);
+        return     (EXIT_FAILURE);
       }
     }
     else {                                        /* If found an option name */
@@ -117,15 +117,15 @@ char *                      argv[])
         case 'H' :                                /* Give the usage message */
         case 'h' :
           usagePrint (stdout, C_usageList);
-          return     (0);
+          return     (EXIT_SUCCESS);
         case 'V' :
           fprintf (stderr, "gscat, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2009-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS, France\n");
-          fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
-          return  (0);
+          fprintf (stderr, SCOTCH_COPYRIGHT_STRING "\n");
+          fprintf (stderr, SCOTCH_LICENSE_STRING "\n");
+          return  (EXIT_SUCCESS);
         default :
           errorPrint ("main: unprocessed option '%s'", argv[i]);
-          return     (1);
+          return     (EXIT_FAILURE);
       }
     }
   }
@@ -136,7 +136,7 @@ char *                      argv[])
 
   fileBlockClose (C_fileTab, 1);                  /* Always close explicitely to end eventual (un)compression tasks */
 
-  return (0);
+  return (EXIT_SUCCESS);
 }
 
 static
