@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010-2012,2014,2018,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -45,7 +45,7 @@
 /**                # Version 5.1  : from : 01 jul 2010     **/
 /**                                 to   : 14 feb 2011     **/
 /**                # Version 6.0  : from : 01 jan 2012     **/
-/**                                 to   : 10 jul 2018     **/
+/**                                 to   : 17 apr 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -118,7 +118,7 @@ char *                      argv[])
 
   if ((argc >= 2) && (argv[1][0] == '?')) {       /* If need for help */
     usagePrint (stdout, C_usageList);
-    return     (0);
+    return     (EXIT_SUCCESS);
   }
 
   fileBlockInit (C_fileTab, C_FILENBR);           /* Set default stream pointers */
@@ -129,7 +129,7 @@ char *                      argv[])
         fileBlockName (C_fileTab, C_fileNum ++) = argv[i];
       else {
         errorPrint ("main: too many file names given");
-        return     (1);
+        return     (EXIT_FAILURE);
       }
     }
     else {                                       /* If found an option name */
@@ -137,7 +137,7 @@ char *                      argv[])
         case 'H' :                               /* Give help */
         case 'h' :
           usagePrint (stdout, C_usageList);
-          return     (0);
+          return     (EXIT_SUCCESS);
         case 'I' :                               /* Select input file type */
         case 'i' :
           for (j = 0; C_inpFormatTab[j].code != '\0'; j ++) { /* Find proper format code */
@@ -149,7 +149,7 @@ char *                      argv[])
           }
           if (C_inpFormatTab[j].code == '\0') {
             errorPrint ("main: unprocessed option '%s'", argv[i]);
-            return     (1);
+            return     (EXIT_FAILURE);
           }
           break;
         case 'O' :                               /* Select input file type */
@@ -163,17 +163,17 @@ char *                      argv[])
           }
           if (C_inpFormatTab[j].code == '\0') {
             errorPrint ("main: unprocessed option '%s'", argv[i]);
-            return     (1);
+            return     (EXIT_FAILURE);
           }
           break;
         case 'V' :
           fprintf (stderr, "mcv, version " SCOTCH_VERSION_STRING "\n");
-          fprintf (stderr, "Copyright 2004,2007,2008,2010-2012,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS, France\n");
-          fprintf (stderr, "This software is libre/free software under CeCILL-C -- see the user's manual for more information\n");
-          return  (0);
+          fprintf (stderr, SCOTCH_COPYRIGHT_STRING "\n");
+          fprintf (stderr, SCOTCH_LICENSE_STRING "\n");
+          return  (EXIT_SUCCESS);
         default :
           errorPrint ("main: unprocessed option '%s'", argv[i]);
-          return     (1);
+          return     (EXIT_FAILURE);
       }
     }
   }
@@ -186,7 +186,7 @@ char *                      argv[])
 #ifdef SCOTCH_DEBUG_ALL
   if (SCOTCH_meshCheck (&meshdat) != 0) {
     errorPrint ("main: bad graph structure");
-    return (1);
+    return     (EXIT_FAILURE);
   }
 #endif /* SCOTCH_DEBUG_ALL */
   C_outFormatTab[C_outFormatType].func (&meshdat, &geomdat, C_filepntrsrcout, C_filepntrgeoout, C_outFormatData);
@@ -196,5 +196,5 @@ char *                      argv[])
   SCOTCH_geomExit (&geomdat);
   SCOTCH_meshExit (&meshdat);
 
-  return (0);
+  return (EXIT_SUCCESS);
 }
